@@ -1,35 +1,54 @@
+##################################################
+## STATFOX: Statistical Functions or Advanced Analytics
+##################################################
+
+##################################################
+## Author: Devin D. Whitten, MS
+## Copyright: Copyright 2020, STATFOX
+## License: MIT
+## Email: devin.d.whitten@gmail.com
+## Status: in development
+##################################################
+
+# Libs
 
 import numpy as np
 import pandas as pd
+import MAD
 import pickle as pkl
 import parmap
 import emcee, corner
-from scipy.stats import gaussian_kde
-from matplotlib.transforms import Affine2D
 import matplotlib.pyplot as plt
-from scipy.interpolate import RegularGridInterpolator
+from matplotlib.transforms import Affine2D
+from matplotlib.ticker import (MultipleLocator, FormatStrFormatter,
+                               AutoMinorLocator)
 import scipy
-from scipy.interpolate import LinearNDInterpolator as LinearND
-from scipy.stats import skewnorm, norm
 from scipy import integrate
-from scipy.optimize import fminbound
-from scipy.optimize import minimize, curve_fit
+from scipy.interpolate import RegularGridInterpolator
+from scipy.interpolate import LinearNDInterpolator as LinearND
+from scipy.stats import skewnorm, norm, gaussian_kde
+from scipy.optimize import fminbound, minimize, curve_fit
 from scipy.interpolate import interp1d
 from scipy.stats import binned_statistic_2d
 from statsmodels.nonparametric.kde import KDEUnivariate
-from matplotlib.ticker import (MultipleLocator, FormatStrFormatter,
-                               AutoMinorLocator)
+
 
 
 ############################################################
 def MAD(array):
+
+    ### Median Absolute Deviation
     return np.median(np.abs(array - np.median(array)))
 
 def S_MAD(array):
+
+    ### Gaussian equivalent MAD scaling
     return MAD(array)/0.6745
 
 
 def print_columns(FRAME):
+
+    ### Easy list-all for Pandas Dataframes in Jupyter Notebooks
     for column in FRAME:
         print(column)
 
@@ -37,8 +56,9 @@ def print_columns(FRAME):
 
 
 def resample(input_array, frac = 0.8):
+
     ### Basic bootstrap iteration
-    ## sample with replacement
+    ### sample with replacement
 
     size = int(frac * len(input_array))
     reindex = np.random.choice(np.random.randint(0, size, size),
@@ -50,6 +70,8 @@ def resample(input_array, frac = 0.8):
 
 def resample_frame(input_frame, frac = 0.8):
 
+    ### Bootstrap resampling with Pandas dataframe
+
     size = int(frac * len(input_frame))
     reindex = np.random.choice(np.random.randint(0, size, size),
                                    size = size, replace=True)
@@ -58,8 +80,9 @@ def resample_frame(input_frame, frac = 0.8):
 
 
 def gen_kde_pdf(distribution, bounds=None, kde_width = None):
-    ## boundary correction for KDE
 
+    ## Probability Density Function with Kernel Density Estimation
+    ## Includes boundary correction, using basic reflection solution.
     if bounds == None:
         print("\t setting bounds to max value")
         var_min, var_max = min(distribution), max(distribution)
